@@ -24,11 +24,11 @@ package Palm::PDB;
 # See http://www.palmos.com/dev/tech/docs/fileformats.zip
 # for details.
 
+use 5.006;
 use strict;
-use vars qw( $VERSION %PDBHandlers %PRCHandlers );
 
-$VERSION = '1.015';
-# This file is part of Palm-PDB 1.015 (August 9, 2014)
+our $VERSION = '1.016';
+# This file is part of Palm-PDB 1.016 (January 24, 2015)
 
 # ABSTRACT: Parse Palm database files
 
@@ -49,8 +49,8 @@ use constant 1.03 { # accepts hash reference
   IndexRsrcLen => 10,			# Length of resource index entry
 };
 
-%PDBHandlers = ();			# Record handler map
-%PRCHandlers = ();			# Resource handler map
+our %PDBHandlers = ();			# Record handler map
+our %PRCHandlers = ();			# Resource handler map
 
 
 sub new
@@ -723,6 +723,7 @@ sub Write
 	my $self = shift;
 	my $fname = shift;		# Output file name
 	my @record_data;
+	my @deleted_records;
 
 	die "Can't write a database with no name\n"
 		unless $self->{name} ne "";
@@ -763,7 +764,7 @@ sub Write
 		}
 		# Figure out size of index
 		$index_len = RecIndexHeaderLen +
-			($#record_data + 1) * IndexRsrcLen;
+			@record_data * IndexRsrcLen;
 	} else {
 		my $record;
 
@@ -804,12 +805,19 @@ sub Write
 			$id = $record->{id};
 
 			$data = $self->PackRecord($record);
+			if ($attributes & 0x80) {
+			    push @deleted_records, [ $attributes, $id, $data ];
+			}
+			else {
+			    push @record_data, [ $attributes, $id, $data ];
+			}
 
-			push @record_data, [ $attributes, $id, $data ];
 		}
+		# put deleted records at end (RT#101666)
+		push @record_data, @deleted_records;
 		# Figure out size of index
 		$index_len = RecIndexHeaderLen +
-			($#record_data + 1) * IndexRecLen;
+			@record_data * IndexRecLen;
 	}
 
 	my $header;
@@ -891,7 +899,7 @@ sub Write
 	# Write index header
 	my $index_header;
 
-	$index_header = pack "N n", 0, ($#record_data+1);
+	$index_header = pack "N n", 0, scalar @record_data;
 	print $handle "$index_header";
 
 	# Write index
@@ -1063,7 +1071,7 @@ sub append_Record
 {
 	my $self = shift;
 
-	if ($#_ < 0)
+	unless (@_)
 	{
 		# No arguments given. Create a new record.
 		my $record = $self->new_Record;
@@ -1144,7 +1152,7 @@ sub append_Resource
 {
 	my $self = shift;
 
-	if ($#_ < 0)
+	unless (@_)
 	{
 		# No arguments given. Create a new resource
 		my $resource = $self->new_Resource;
@@ -1258,9 +1266,9 @@ Palm::PDB - Parse Palm database files
 
 =head1 VERSION
 
-This document describes version 1.015 of
-Palm::PDB, released August 9, 2014
-as part of Palm-PDB version 1.015.
+This document describes version 1.016 of
+Palm::PDB, released January 24, 2015
+as part of Palm-PDB version 1.016.
 
 =head1 SYNOPSIS
 
