@@ -18,14 +18,14 @@ package Palm::Raw;
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See either the
 # GNU General Public License or the Artistic License for more details.
 
+use 5.006;
 use strict;
 use Palm::PDB;
-use vars qw( $VERSION @ISA );
 
-$VERSION = '1.015';
-# This file is part of Palm-PDB 1.015 (August 9, 2014)
+our $VERSION = '1.016'; # VERSION
+# This file is part of Palm-PDB 1.016 (January 24, 2015)
 
-@ISA = qw( Palm::PDB );
+our @ISA = qw( Palm::PDB );
 
 # ABSTRACT: Handler for "raw" Palm databases
 
@@ -115,9 +115,9 @@ Palm::Raw - Handler for "raw" Palm databases
 
 =head1 VERSION
 
-This document describes version 1.015 of
-Palm::Raw, released August 9, 2014
-as part of Palm-PDB version 1.015.
+This document describes version 1.016 of
+Palm::Raw, released January 24, 2015
+as part of Palm-PDB version 1.016.
 
 =head1 SYNOPSIS
 
